#ifndef SEARCHPAGE_H
#define SEARCHPAGE_H

typedef struct _pagetype {
	//int			pageNo;
	int			results;
	struct _pagetype *	next;
} PAGETYPE;


class searchPage {
	public:
		searchPage();
		~searchPage();
		void clearPages();
		BOOL addPage(int results);
		int totalPages();
		int pageResults(int pageNo);
		BOOL setCurrent(int curr);
		int getCurrent();
		BOOL currentIsEnd();
		BOOL currentNext();
		BOOL currentPrev();
		int foundSum();
		int foundSum(int pageNo);


	private:

		PAGETYPE * head;
		PAGETYPE * ptrA;
		PAGETYPE * ptrB;

		int currentPage;
		int NumPages;

};

searchPage::searchPage() {
	head = NULL;
	ptrA = NULL;
	ptrB = NULL;

	NumPages = 0;
	currentPage = 0;
}


searchPage::~searchPage() {
	clearPages();
}


BOOL searchPage::currentIsEnd() {
	return (currentPage == NumPages);
}


BOOL searchPage::setCurrent(int curr) {

	if (curr < 0)
		return FALSE;
	if (curr > NumPages)
		return FALSE;

	currentPage = curr;

	return TRUE;

}

BOOL searchPage::currentPrev() {

	if (currentPage <= 0) {
		currentPage = 0;
		return FALSE;
	}
	else {
		currentPage--;
		return TRUE;
	}

}

BOOL searchPage::currentNext() {

	if (currentPage >= NumPages) {
		currentPage = NumPages;
		return FALSE;
	}
	else {
		currentPage++;
		return TRUE;
	}


}



int searchPage::getCurrent() {

	return currentPage;

}

int searchPage::foundSum() {
	return foundSum(currentPage);
}

int searchPage::foundSum(int pageNo) {
	int count=0;
	int i=0;

	if (pageNo < 0)
		return -1;

	if (pageNo > NumPages)
		return -1;

	if (pageNo == 0)
		return 0;

	for (i=1; i<=pageNo; i++)
		count += pageResults(i);

	return count;

}



int searchPage::pageResults(int pageNo) {

	if (pageNo > NumPages)
		return -1; //ERROR

	if (NumPages == 0)
		return -1; //ERROR

	if (pageNo < 0)
		return -1; //ERROR

	if (pageNo == 0)
		return 0;

	ptrA = head;

	//should skip first case if pageNo == 1;
	for (int i=1; i<pageNo; i++) 
		ptrA = ptrA->next;

	return ptrA->results;

	
}

int searchPage::totalPages() {
	return NumPages;
}

BOOL searchPage::addPage(int results) {
	if (results <= 0) { //must be positive
		return FALSE; //bad result number
	}

	if (head == NULL) {
		//First Page
		head = new PAGETYPE;
		if (!head) 
			return FALSE; //error allocating memory
			
		//head->pageNo = 0;
		head->results = results;
		head->next = NULL;

		NumPages = 1;
	} else {

		ptrA = head;
		while (ptrA->next != NULL)
			ptrA = ptrA->next;

		ptrA->next = new PAGETYPE;
		if (!ptrA->next)
			return FALSE; //error allocating memory

		ptrA = ptrA->next;  //update values
		ptrA->results = results;
		ptrA->next = NULL;

		NumPages++; //increment number of pages
	}

	return TRUE;


}


void searchPage::clearPages() {
	ptrA = head;
	head = NULL;

	while (ptrA != NULL) {
		ptrB = ptrA->next;
		delete ptrA;
		ptrA = ptrB;
	}

	NumPages = 0;
	currentPage = 0;
}

#endif